@@ -8,7 +8,7 @@ use Getopt::Long 'GetOptions';
 use Pod::Usage 'pod2usage';
 use Proc::PID::File;
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 use constant EXPORT_OK => [ qw( options pod2usage singleton ) ];
 
@@ -29,10 +29,24 @@ sub import {
     }
 
     if ( grep { $_ eq 'singleton' } @_ ) {
-        if ( Proc::PID::File->running ) {
-            warn "Running as singleton; forcing exit of $0\n";
-            exit 1;
-        }
+        my @dirs = (
+            '/var/run',
+            '/tmp',
+            $ENV{HOME},
+            '.',
+            '/',
+        );
+
+        my $singleton;
+        eval {
+            if ( Proc::PID::File->running({ dir => shift @dirs }) ) {
+                warn "Running as singleton; forcing exit of $0\n";
+                exit 1;
+            }
+            $singleton = 1;
+        } while ( not $singleton and @dirs );
+
+        die "Unable to establish PID file for singleton functionality\n" unless ($singleton);
     }
 
     options() if ( grep { $_ eq 'podhelp' } @_ );
@@ -66,7 +80,7 @@ Util::CommandLine - Command-line interface helper utility
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Util-CommandLine.svg)](https://travis-ci.org/gryphonshafer/Util-CommandLine)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Util-CommandLine/badge.png)](https://coveralls.io/r/gryphonshafer/Util-CommandLine)
